@@ -15,7 +15,7 @@ class DatabaseConnection(dict):
         elif self['engine'] == 'sqlite':
             return f"sqlite:///{self['name']}"
         else:
-            raise NotImplementedError
+            raise NotImplementedError # pragma: no cover
 
     def as_engine(self, create_engine, *args, **kwargs):
         """Return a :class:`sqlalchemy.engine.Engine` instance configured
